using System;
using System.Collections;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "a red skeletal corpse" )]
	public class RedSkeleton : BaseCreature
	{
		[Constructable]
		public RedSkeleton() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a red skeleton";
			Body = Utility.RandomList( 50, 56 );
			BaseSoundID = 0x48D;
			Hue = 1157;

			SetStr( 600, 700 );
			SetDex( 56, 75 );
			SetInt( 16, 40 );

			SetHits( 1000, 1100 );

			SetDamage( 70, 50 );

			SetDamageType( ResistanceType.Physical, 100 );

			SetResistance( ResistanceType.Physical, 15, 20 );
			SetResistance( ResistanceType.Fire, 5, 10 );
			SetResistance( ResistanceType.Cold, 25, 40 );
			SetResistance( ResistanceType.Poison, 25, 35 );
			SetResistance( ResistanceType.Energy, 5, 15 );

			SetSkill( SkillName.MagicResist, 45.1, 60.0 );
			SetSkill( SkillName.Tactics, 45.1, 60.0 );
			SetSkill( SkillName.Wrestling, 45.1, 55.0 );

			Fame = 450;
			Karma = -450;

			VirtualArmor = 16;
			
			PackItem( new RedBone() );

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new RedBoneArms() ); break;
				case 1: PackItem( new RedBoneChest() ); break;
				case 2: PackItem( new RedBoneGloves() ); break;
				case 3: PackItem( new RedBoneLegs() ); break;
				case 4: PackItem( new RedBoneHelmet() ); break;
				case 5: PackItem( new RedBoneAxe() ); break; 
			}
		}

		public override void GenerateLoot()
		{
			AddLoot( LootPack.Poor );
		}

		public override Poison PoisonImmune{ get{ return Poison.Lesser; } }

		public RedSkeleton( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
